local ADDON_NAME, addonTable = ...

local ElkFactions = LibStub("AceAddon-3.0"):GetAddon("ElkFactions")
local cfgreg = LibStub("AceConfigRegistry-3.0")

local colorTable = {
	none = "none",
	atWar = "\"At War\" state",
	standingBlizzard = "Standing (Blizzard)",
	standingIncremential = "Standing (ElkFactions)",
	standingIncrementialOld = "Standing (FactionsFu)",
	delta = "Delta",
}

local optionsTable = {
	type = "group",
	args = {
		minimapButton = {
			name = "Minimap Button",
			order = 1,
			type = "group",
			inline = true,
			args = {
				minimapButtonEnabled = {
					name = "Enabled",
					type = "toggle",
					get = function(info)
							return not ElkFactions.db.profile.minimap.hide
						end,
					set = function(info, value)
							ElkFactions.db.profile.minimap.hide = not value
							LibStub("LibDBIcon-1.0"):Refresh("ElkFactions")
						end
				},
			},
		},
		tooltipColors = {
			name = "Tooltip Colors",
			order = 2,
			type = "group",
			inline = true,
			args = {
				tooltipColorName = {
					name = "Name",
					order = 1,
					type = "select",
					style = "dropdown",
					values = colorTable,
				},
				tooltipColorStandingText = {
					name = "Standing",
					order = 2,
					type = "select",
					style = "dropdown",
					values = colorTable,
				},
				tooltipColorStandingValueAbsolute = {
					name = "Value (absolute)",
					order = 3,
					type = "select",
					style = "dropdown",
					values = colorTable,
				},
				tooltipColorStandingValuePercent = {
					name = "Value (percent)",
					order = 4,
					type = "select",
					style = "dropdown",
					values = colorTable,
				},
				tooltipColorStandingValueDelta = {
					name = "Delta",
					order = 5,
					type = "select",
					style = "dropdown",
					values = colorTable,
				},
			},
			get = function(info)
					return ElkFactions.db.profile[info[#info]]
				end,
			set = function(info, value)
					ElkFactions.db.profile[info[#info]] = value
					ElkFactions:UpdateTooltip()
				end,
		},
		textPatterns = {
			name = "Text Patterns",
			order = 3,
			type = "group",
			inline = true,
			args = {
				patternText = {
					name = "Pattern (Data Object Text)",
					order = 1,
					type = "input",
					width = "double",
				},
				patternChat = {
					name = "Pattern (Chat Inserts)",
					order = 2,
					type = "input",
					width = "double",
				},
				patternDesc01 = {
					name = "Different placeholders are available:",
					order = 51,
					type = "description",
				},
				patternDesc02 = {
					name = [[
Text:
{n}    name
{s}    standing
{rc}   current reputation for this level
{rm}   maximum reputation for this level
{rp}   reputation percentage for this level
{rd}   reputation change this session]],
					order = 52,
					type = "description",
				},
				patternDesc03 = {
					name = [[
Color:
{cw}   at war
{cb}   Blizzard
{ci}   incremential (ElkFactions)
{co}   incremential (FactionsFu)
{cd}   gain/loss this session
{cr}   reset]],
					order = 53,
					type = "description",
				},
			},
			get = function(info)
					return ElkFactions.db.profile[info[#info]]
				end,
			set = function(info, value)
					if value == "" then value = nil end
					ElkFactions.db.profile[info[#info]] = value
					ElkFactions:UpdateText()
				end,
		},
	},
}
LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("ElkFactions", optionsTable)
